from math import pi, sin, cos, asin, sqrt

def harvesini_distance(lat_origin, lon_origin, lat_final, lon_final, sphere_radius: int = 6371000)-> float:
    """Function that uses the harvesini's formula
    to calculate the distance between two points,
    on the surface of a sphere, said function has
    the radius of the sphere set by default as the
    radius of the Earth, but by inputting a given
    radius it can also apply the formula to any sphere.

    Args:
        lat_origin (float): latitude of the origin point
        lon_origin (float): longitude of the origin point
        lat_final (float): latitude of the end point
        lon_final (float): longitude of the end point
        sphere_radius (int, optional): variable of the radius of the sphere, 
        by default it is 6371000 meters.

    Returns:
        float: distance in meters between the two points
    """
    distance_lat = (lat_final - lat_origin) * pi / 180.0
    distance_lon = (lon_final - lon_origin) * pi / 180.0

    lat_origin = lat_origin * pi / 180.0
    lat_final = lat_final * pi / 180.0

    result = sin(distance_lat / 2)**2 + sin(distance_lon / 2)**2* cos(lat_origin) * cos(lat_final)
    angle = 2 * asin(sqrt(result))
    return round(sphere_radius * angle, 3)


import plotly.graph_objects as go
import numpy as np
from matplotlib.colors import is_color_like


def plot_world_map(lat_origin, lon_origin, lat_final, lon_final, user_color: str = 'red') -> None:
    """Function that receives the coordinates of two points and
    makes a plotly plot with both and the line that they trace,
    in red, by default, or a color defined by the user. 

    Args:
        lat_origin (float): latitude of the origin point
        lon_origin (float): longitude of the origin point
        lat_final (float): latitude of the end point
        lon_final (float): longitude of the end point
    """
    if is_color_like(user_color) == False:
        print("You've entered something that's not a color. Please try again")
        return 

    latitudes = [lat_origin, lat_final]
    longitudes = [lon_origin, lon_final]
    fig = go.Figure(go.Scattermapbox(
        mode = "markers+lines",
        lat = latitudes,
        lon = longitudes,
        marker = {'size': 10}))
     
    fig.update_layout(
        margin ={'l':0,'t':0,'b':0,'r':0},
        mapbox = {
            'center': {'lon': np.mean(longitudes), 
                       'lat': np.mean(latitudes)},
            'style': "stamen-terrain",
            'zoom': 3})

    fig.update_traces(line_color=user_color , marker_color=user_color)

    fig.show()



from setuptools import setup, find_packages

with open("README.md", "r") as f:
    page_description = f.read()

with open("requirements.txt") as f:
    requirements = f.read().splitlines()

setup(
    name="earth_distances",
    version="0.0.8",
    author="Gabriel Vinicius Sebastião",
    author_email="gabrielvrsas@gmail.com",
    description="Package focused on Earth distance calculation and plotting",
    long_description=page_description,
    long_description_content_type="text/markdown",
    url="https://tinyurl.com/2p83nw5z",
    packages=find_packages(),
    install_requires=requirements,
    python_requires='>=3.8.5'
)

